Package: imageTCGAutils
Title: Utility functions for working with histopathology images
Version: 1.1.2
Authors@R: c(
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu",
        "aut", c(ORCID = "0000-0002-3242-0582", affiliation = 
            "CUNY Graduate School of Public Health and Health Policy,
            New York, NY USA")),
    person("Ilaria", "Billato", , "ilaria.billato@phd.unipd.it",
        c("aut", "cre"), c(ORCID = "0000-0002-3335-3254", 
        affiliation = "Department of Biology, University of Padova")
    ),
    person("Eslam", "Abousamra", role = "ctb", comment = c(
        affiliation = "CUNY Graduate School of Public Health and Health Policy,
        New York, NY USA")
    ))
Description: Utility functions for working with CONCH data, listing
        remote files. One function assigns HoverNet nuclei to
        ProvGigaPath tiles with a scale factor to align coordinates.
        Provides internal utility functions for 'imageFeatureTCGA' and
        most functions are not meant for end users.
Depends: R (>= 4.5.0)
Imports: BiocBaseUtils, data.table, dplyr, grDevices, methods, rlang,
        S4Vectors, SpatialExperiment, SummarizedExperiment
Suggests: anndataR, BiocStyle, imageFeatureTCGA, ggplot2, knitr, paws,
        rhdf5, rmarkdown, sfdep, spdep, SpatialFeatureExperiment,
        tinytest, wk
biocViews: Software, WorkflowStep, Preprocessing
License: Artistic-2.0
BugReports: https://github.com/waldronlab/imageTCGAutils/issues
URL: https://github.com/waldronlab/imageTCGAutils
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Date: 2026-06-10
Config/pak/sysreqs: libmagick++-dev gsfonts libicu-dev libssl-dev
        zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-06-10 16:10:39 UTC
RemoteUrl: https://github.com/bioc/imageTCGAutils
RemoteRef: HEAD
RemoteSha: ebe0928eaa4af32beabcd170321eb06a712380d3
NeedsCompilation: no
Packaged: 2026-06-10 18:11:34 UTC; root
Author: Marcel Ramos [aut] (ORCID: <https://orcid.org/0000-0002-3242-0582>,
    affiliation: CUNY Graduate School of Public Health and Health
    Policy, New York, NY USA),
  Ilaria Billato [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3335-3254>, affiliation: Department of
    Biology, University of Padova),
  Eslam Abousamra [ctb] (affiliation: CUNY Graduate School of Public
    Health and Health Policy, New York, NY USA)
Maintainer: Ilaria Billato <ilaria.billato@phd.unipd.it>
Built: R 4.6.0; ; 2026-06-10 18:13:38 UTC; unix
