# Generated by roxygen2: do not edit by hand

export(importCONCH)
export(listHoverNet)
export(listProvGiga)
export(matchHoverNetToTiles)
importFrom(BiocBaseUtils,checkInstalled)
importFrom(BiocBaseUtils,isScalarCharacter)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,metadata)
importFrom(SpatialExperiment,spatialCoords)
importFrom(SummarizedExperiment,colData)
importFrom(data.table,":=")
importFrom(data.table,.I)
importFrom(data.table,.N)
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(data.table,setnames)
importFrom(dplyr,mutate)
importFrom(methods,is)
importFrom(rlang,.data)
importFrom(utils,head)
